跳到主要内容

Nonce

结构体 Nonce 

pub struct Nonce(pub [u8; 12]);
展开描述

A nonce. This is unique 用于 all messages on 一个 connection.

Tuple Fields

0: [u8; 12]

实现

Source

impl Nonce

pub fn new(iv: &Iv, seq: u64) -> Self

Combine an Iv 并 sequence number 到 produce 一个 unique nonce.

This is iv ^ seq where seq is encoded as 一个 96-bit big-endian integer.

pub fn for_path(path_id: u32, iv: &Iv, pn: u64) -> Self

Creates 一个 unique nonce based on the iv, the packet number pn 并 multipath path_id

此 nonce is computed as the XOR between the iv 并 the 96-bit big-ending integer formed by concatenating path_idpn

自动 Trait 实现



impl Freeze for Nonce



impl RefUnwindSafe for Nonce



impl Send for Nonce



impl Sync for Nonce



impl Unpin for Nonce



impl UnsafeUnpin for Nonce



impl UnwindSafe for Nonce

Blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows 从 an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows 从 an owned value. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回传入的参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

Calls U::从(self)

That is, this conversion is whatever the implementation of From<T> 用于 U 的实现方式。

Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

转换出错时返回的类型。
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。